<?php defined( '_JEXEC' ) or die( 'Restricted access' );
/**
 * @version 2.0 $Id: helper.php,v 1.12 2009/12/12 21:45:27 harry Exp $
 * @package Joomla
 * @subpackage H2N Link Directory dTree 2.0 Modul
 * @copyright (C) 2008 - 2009 Harry Klein - www.joomla-hklein.de
 * @Copyright (C) 2006 Soner (pisdoktor) Ekici - www.sonerekici.com
 * @license GNU/GPL, see LICENSE.php
 * 
 * H2N Link Directory dTree 2 Modul is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.
 *
 * H2N Link Directory dTree 2 Modul is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EventList; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

class mod_ld_dtree_Helper {
	const ROOT_CATID='root_catid';
	const CAT_LEVEL='cat_level';
	const CLOSE_SAME_LEVEL='closesamelevel';
	const VIEW_TREE_ICONS='viewTreeIcons';
	const USE_ROOT_ELEMENT_LABEL='useRootElementLabel';
	const ROOT_ELEMENT_LABEL='rootElementLabel';
	const ORDER_BY='orderBy';
	const LABEL_SOURCE='labelSource';
	const USE_LD2_IF_LD_AVAILABLE='useLd2IfLdAvailable';
	
	/**
	 * Liefert die URL zur Javascript-Datei von dtree
	 * @return URK zur zur Javascript-Datei von dtree
	 */
	public function getJsURL(){
		return JURI::base().'includes/js/dtree/dtree.js';
	}

	/**
	 * Liefert die URL zu den Image-Dateien von dtree
	 * @return URL zu den Image-Dateien von dtree
	 */
	public function getImgURL(){
		return JURI::base().'includes/js/dtree/img/';
	}

	/**
	 * Liefert die URL zur CSS-Datei von dtree
	 * @return URL zur CSS-Datei von dtree
	 */
	public function getCssURL(){
		return JURI::base().'includes/js/dtree/dtree.css';
	}

	/**
	 * Liefert den Modul-Parameter CloseSameLevel
	 * @param JParameter $params Modul-Parameter
	 * @return Modul-Parameter CloseSameLevel
	 */
	public function getCloseSameLevel(JParameter &$params){
		return (bool)intval($params->get(self::CLOSE_SAME_LEVEL, 1 ));
	}
	
	/**
	 * Liefert true, wenn die Icon vor den Label angezeigt werden sollen
	 * @param JParamter $params Modul-Parameter
	 * @return Modul-Parameter ViewTreeIcons
	 */
	public function getViewTreeIcons(JParameter &$params){
		return (bool)intval($params->get(self::VIEW_TREE_ICONS, 1 ));
	}

	/**
	 * Baut den Javascript-Code für den Kategorien-Bau zusammen
	 *
	 * @param JParameter $Modul-Parameter
	 * @return Javascript für den Kategorieen-Baum oder leer, wenn Komponente 
	 * 		com_linkdirectory nicht installiert bzw. nicht aktiviert ist.
	 */
	public function getdTree(JParameter &$params){
		if (! (JComponentHelper::isEnabled('com_linkdirectory',true) || 
			  (JComponentHelper::isEnabled('com_linkdirectory2',true) ))) return;

		$root_catid=intval($params->get(self::ROOT_CATID, 0 ));
		$cat_level=intval($params->get(self::CAT_LEVEL, 2 ));
		$useRootElementLabel=intval($params->get(self::USE_ROOT_ELEMENT_LABEL, 1 ));
		$useLd2IfLdAvailable=(bool)intval($params->get(self::USE_LD2_IF_LD_AVAILABLE, 1 ));
		if ($useRootElementLabel) {
			$rootElementLabel=$params->get(self::ROOT_ELEMENT_LABEL, '' );
			if (trim($rootElementLabel) == ''){
				$rootElementUrl='';
			} else {
				$rootElementUrl=self::getLinkUrl(null,0,$useLd2IfLdAvailable);
			}
		} else {
			$rootElementLabel=JText::_('LD TREE ROOT ELEMENT DEFAULT LABEL');
			$rootElementUrl=self::getLinkUrl(null,0,$useLd2IfLdAvailable);
		}
		
		$labelSource=self::_buildSelectSource($params);	
		$orderBy=self::_buildAndSetContentOrderBy($params);		
		
		$out='';
		$database=&JFactory::getDBO();
		$cats=self::getChildren( $root_catid, $cat_level, $labelSource, $orderBy );
		if ( $root_catid == 0 ) {
			$out .= self::buildDTreeItem(0,-1,$rootElementLabel,$rootElementUrl);
		} else {
			$database->setQuery( 'SELECT ' . $labelSource . ',id FROM #__ldcats WHERE published=1 AND id=' . $root_catid);
			$name=$database->loadResult();
			if ($name <> NULL) {
				$out.=self::buildDTreeItem($root_catid,-1,$name,self::getLinkUrl('viewcat',$root_catid,$useLd2IfLdAvailable));
			}
		}
		foreach( $cats AS $cat ) {
			$out.=self::buildDTreeItem($cat->id,$cat->parent_id,$cat->name,self::getLinkUrl('viewcat',$cat->id,$useLd2IfLdAvailable));
		}
		return $out;
	}

	/**
	 * Liefert ein DTree-Item als Javascript
	 *
	 * @param int $catid Id der Kategorie
	 * @param int $parent_catid Id der Parent-Kategorie
	 * @param String $name Name der Kategorie
	 * @param String $url URL zur Kategorie
	 * @return String dTree Item als Javascript
	 */
	private function buildDTreeItem($catid, $parent_catid, $name, $url){
		return "\n d.add($catid ,$parent_catid,'".htmlspecialchars($name, ENT_QUOTES )."','". $url."');";
	}

	private function getChildren($cat_id, $cat_level, $labelSource, $orderBy){
		$database=&JFactory::getDBO();
		$cat_ids=array();
		if ( $cat_level > 0  ) {
			$sql='SELECT id, ' . $labelSource .', parent_id FROM #__ldcats WHERE published=1 AND parent_id='.$cat_id . $orderBy;
			$database->setQuery( $sql );
			$cat_ids=$database->loadObjectList();
			if ( count($cat_ids) ) {
				foreach( $cat_ids AS $cid ) {
					$children_ids=self::getChildren( $cid->id, ($cat_level-1), $labelSource, $orderBy );
					$cat_ids=array_merge( $cat_ids, $children_ids );
				}
			}
		}
		return $cat_ids;
	}

	/**
	 * Ermittelt die URL zur Anzeige von Kategorien in com_linkdirectory
	 *
	 * @param string $task Task, der auf com_linkdirectory ausgeführt werden soll 
	 * @param int $catid Id der Kategorie
	 * @return URL
	 */
	private function getLinkUrl($task=NULL,$catid=NULL,$useLd2IfLdavailable){
		$option='com_linkdirectory';
		if ( JComponentHelper:: isEnabled('com_linkdirectory',true)) {
			if ( (JComponentHelper:: isEnabled('com_linkdirectory2',true)) && ($useLd2IfLdavailable)){
					$option='com_linkdirectory2&view=categories';
			}
		} else {
			$option='com_linkdirectory2&view=categories';
		}
		$url='index.php?option='.$option;
		if ($task) $url.='&task='.$task;
		if ($catid) $url.='&catid='.$catid;
		return JRoute::_($url);
	}

	private function _buildAndSetContentOrderBy(&$params){ 
		switch ($params->get(self::ORDER_BY, '' )){
			case 'non': 
				return ' ';
				break;
			case 'name': 
				return ' ORDER BY name ASC ';
				break;
			case 'title':
				return ' ORDER BY title ASC ';
				break;
			case 'ordering': 
			default:
				return ' ORDER BY ordering ASC ';		
		}
	}
	
	private function _buildSelectSource(&$params){
		switch($params->get(self::LABEL_SOURCE)){
			case 'title':
				return 'title AS name ';
				break;
			case 'name':
			default:
				return 'name';
		}
	}
}
?>